api

package
v0.0.0-...-7c34a35 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 29, 2025 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package api provides the HTTP server implementation for serving requests related to banking services, including user authentication, account management, and transaction processing.

Index

Constants

This section is empty.

Variables

var ErrBindingError = errors.New("coulnd't bind any validators")

Functions

This section is empty.

Types

type Server

type Server struct {
	// contains filtered or unexported fields
}

Server serves HTTP requests for our banking service

func NewServer

func NewServer(config util.Config, store db.Store) (*Server, error)

NewServer creates a new HTTP server and setup routing.

func (*Server) Start

func (server *Server) Start(address string) error

Jump to